@@ -1,6 +1,6 @@
 from .conf import settings
 
-from .stream import send
+from .stream import send, send_buff
 from .measure import *
 from .decorators import *
 from .profile import *
