@@ -20,7 +20,7 @@ def send_buff(port, buff):
     msg = "\n".join(buff)
     msg += "\n"
     _carbon_socket.sendto(msg,
-                          (settings.CARBON_SERVER,
+                          (settings.CARBON_HOST,
                            port))
 
 def send(metric, value, stamp=None, aggregator=False):
